//+------------------------------------------------------------------+
//|                                                    SignalITF.mqh |
//|                   Copyright 2009-2013, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#include <Expert\ExpertSignal.mqh>
// wizard description start
//+------------------------------------------------------------------+
//| Description of the class                                         |
//| Title=Simpler intraday time filter                               |
//| Type=SignalAdvanced                                              |
//| Name=SimplerIntradayTimeFilter                                   |
//| ShortName=SITF                                                   |
//| Class=CSignalITF                                                 |
//| Page=signal_time_filter                                          |
//| Parameter=StartTime,string,00:00,Start Time                      |
//| Parameter=EndTime,string,00:00,End Time                          |
//+------------------------------------------------------------------+
// wizard description end
//+------------------------------------------------------------------+
//| Class CSignalITF.                                                |
//| Appointment: Class trading signals time filter.                  |
//|              Derives from class CExpertSignal.                   |
//+------------------------------------------------------------------+
class CSignalITF : public CExpertSignal
  {
protected:
   //--- input parameters
   string            m_start_time;
   string            m_end_time;

public:
                     CSignalITF(void);
                    ~CSignalITF(void);
   //--- method of verification of settings
   virtual bool      ValidationSettings(void);                    
   //--- methods initialize protected data
   void              StartTime(string value)  { m_start_time=value; }
   void              EndTime(string value)    { m_end_time=value;   }
   bool              IsTradingTime(void);

   //--- methods of checking conditions of entering the market
   virtual double    Direction(void);
  };
//+------------------------------------------------------------------+
//| Constructor                                                      |
//+------------------------------------------------------------------+
CSignalITF::CSignalITF(void) : m_start_time("00:00"),
                               m_end_time("00:00")
  {
  }
//+------------------------------------------------------------------+
//| Destructor                                                       |
//+------------------------------------------------------------------+
CSignalITF::~CSignalITF(void)
  {
  }
//+------------------------------------------------------------------+
//| Validation settings protected data.                              |
//+------------------------------------------------------------------+
bool CSignalITF::ValidationSettings(void)
  {
//--- validation settings of additional filters
   if(!CExpertSignal::ValidationSettings())
      return(false);
//--- initial data checks
   if(m_start_time=="" || m_start_time=="")
     {
      printf(__FUNCTION__+": Start time and end time must not be empty");
      return(false);
     }
//--- ok
   return(true);
  }  
//+------------------------------------------------------------------+
//| Check conditions for time filter.                                |
//+------------------------------------------------------------------+
double CSignalITF::Direction(void)
  {
   if(!IsTradingTime())
      return(EMPTY_VALUE); 
//--- condition OK
   return(0.0);
  }
  
bool CSignalITF::IsTradingTime(void)
  {
   bool result=false;
   datetime start = StringToTime(m_start_time);
   datetime end   = StringToTime(m_end_time);
   datetime dt    = TimeTradeServer();
//---
   if(start<end) if(dt>=start && dt<end)  result=true;  //between range
   if(start>=end) if(dt>=start || dt<end) result=true;  //turned off
//---
   return(result);
  }  
//+------------------------------------------------------------------+
